from .stats import stats
from .zbcode import get_tree
from .regcode import get_reg
import argparse
from tabulate import tabulate

def main():
    parser=argparse.ArgumentParser(prog='cn-stats',description='获取中国国家统计局网站数据Python包')
    parser.add_argument('--tree', action='store_const', const='zb', help='列出指标代码')
    parser.add_argument('--list-regcode', action='store_const', const='list_regcode', help='列出地区代码, 默认列出分省地区代码，列出主要城市代码添加 --dbcode csnd 参数')
    parser.add_argument('--dbcode', nargs='?', const='hgyd', default='hgyd', help='数据库代码, 默认: hgyd(宏观月度), 可选: hgjd(宏观季度), hgnd(宏观年度), fsyd(分省月度), fsjd(分省季度), fsnd(分省年度), csyd(城市月度), csjd(城市季度), csnd(城市年度)')
    parser.add_argument('--regcode', nargs='?', help='地区代码, 例如: 110000 是北京市')
    parser.add_argument('zbcode', help='指标代码', nargs='?')
    parser.add_argument('date', help='查询日期', nargs='?')
    args=parser.parse_args()
    if args.tree == 'zb':
        get_tree(args.tree, args.dbcode)
    elif args.list_regcode == 'list_regcode':
        if args.dbcode[:2] == 'cs':
            for n in get_reg('csnd'):
                print(n['code'], n['name'])
        else:
            for n in get_reg():
                print(n['code'], n['name'])
    else:
        # 如果 regcode 有值，并且后4位是0, dbcode等于fsyd,否则dbcode是csyd
        if args.regcode:
            if args.regcode[-4:] == '0000':
                args.dbcode='fsyd'
            else:
                args.dbcode='csyd'
        # print(args)
        r=stats(args.zbcode, args.date, args.regcode, args.dbcode)
        headers = ["指标名称", "指标代码", "查询日期", "数值"]
        print(tabulate(r, headers=headers, tablefmt="pretty"))

if __name__ == '__main__':
    main()



import cnstats

def test_import():
    assert cnstats is not None
    print("\nSuccessfully imported cnstats")

def test_version():
    # Simple check if we can access some attributes if they exist
    # Since I don't know the exact internal structure deeply yet, 
    # just confirming the package is findable.
    import cnstats.zbcode
    assert cnstats.zbcode is not None



from tabulate import tabulate

def test_table_format():
    sample_data = [
        ["指标 A", "A01", "202201", "100.5"],
        ["指标 B", "B02", "202202", "200.0"],
        ["测试长文本指标名称对齐情况", "C03", "202203", "300.75"]
    ]
    headers = ["指标名称", "指标代码", "查询日期", "数值"]
    
    # 使用与 __main__.py 相同的配置
    output = tabulate(sample_data, headers=headers, tablefmt="pretty")
    print("\n验证表格输出效果：")
    print(output)

if __name__ == "__main__":
    test_table_format()



from .common import easyquery

def stats(zbcode, datestr, regcode=None, dbcode='hgyd'):
    wds=[]
    dfwds=[]
    if zbcode:
        dfwds.append({"wdcode":"zb","valuecode":zbcode})

    if datestr:
        dfwds.append({"wdcode":"sj","valuecode":datestr})
    
    if regcode:
        wds.append({"wdcode":"reg","valuecode":regcode})

    ret=easyquery(dbcode=dbcode, dfwds=dfwds)
    if ret['returncode'] == 200 :
        data_dict = {}
        for n in ret['returndata']['wdnodes']:
            if n['wdcode'] == 'zb':
                data_dict['zb'] = {}
                for i in n['nodes']:
                    data_dict['zb'][i['code']] = i['cname']
            if n['wdcode'] == 'sj':
                data_dict['sj'] = {}
                for i in n['nodes']:
                    data_dict['sj'][i['code']] = i['cname']
            if n['wdcode'] == 'reg':
                data_dict['reg'] = {}
                for i in n['nodes']:
                    data_dict['reg'][i['code']] = i['cname']

        result = []
        for n in ret['returndata']['datanodes']:
            if n['data']['hasdata'] == True:
                if len(data_dict) == 2:
                    result.append(
                        [data_dict['zb'][n['wds'][0]['valuecode']],
                        n['wds'][0]['valuecode'],
                        n['wds'][1]['valuecode'],
                        n['data']['strdata']])
                if len(data_dict) == 3:
                    result.append(
                        [data_dict['zb'][n['wds'][0]['valuecode']],
                        n['wds'][0]['valuecode'],
                        n['wds'][1]['valuecode'],
                        n['wds'][2]['valuecode'],
                        n['data']['strdata']])
        return result


import requests
import time
import json

_header={
        'Accept-Encoding':'gzip, deflate, br',
        'Connection':'keep-alive',
        'Referer':'https://data.stats.gov.cn/easyquery.htm?cn=A01',
        'Host':'data.stats.gov.cn',
        'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.4844.51 Safari/537.36 Edg/99.0.1150.36',
        'X-Requested-With':'XMLHttpRequest',
        'Cookie':'_trs_uv=l0krufmy_6_30qm; JSESSIONID=JkGLaObMfWG3_P3_bNKa59cUydvE_nJDUpJOsskem4S-E-wgJeA7!-2135294552; u=1'
       }

def _random_timestamp():
    return str(int(round(time.time() * 1000)))

def easyquery(m='QueryData', dbcode='hgyd', rowcode='zb', colcode='sj', wds=[], dfwds=[], id=None, wdcode=None):
    url='https://data.stats.gov.cn/easyquery.htm'
    obj={
        'm': m,
        'dbcode': dbcode,
        'rowcode': rowcode,
        'colcode': colcode,
        'wds': json.dumps(wds),
        'dfwds': json.dumps(dfwds),
        'k1': _random_timestamp(),
        'h': '1',
        }
    if id: obj['id'] = id
    if wdcode: obj['wdcode'] = wdcode
    requests.packages.urllib3.disable_warnings()
    session = requests.Session()
    session.trust_env = False
    r = session.post(url, data=obj, headers=_header, verify=False)
    return r.json()


from .common import easyquery

def get_reg(dbcode='fsyd'):
    wds=[{"wdcode":"zb","valuecode":"A01010101"}]
    ret = easyquery(dbcode=dbcode, rowcode='reg', wds=wds)
    if ret['returncode'] == 200:
        return ret['returndata']['wdnodes'][1]['nodes']
        
if __name__ == '__main__':
    for n in get_reg():
        print(n['code'], n['name'])



from .common import easyquery

def get_tree(id='zb', dbcode='hgyd'):
    for n in easyquery(m='getTree', dbcode=dbcode, wdcode='zb', id=id):
        print(n['id'], n['name'])
        if n['isParent']: get_tree(n['id'], dbcode)

if __name__ == '__main__':
    get_tree('zb')